@@ -3,7 +3,7 @@ package Log::Saftpresse::CountersOutput::Html;
 use Moose;
 
 # ABSTRACT: plugin to output counters in HTML report
-our $VERSION = '1.0'; # VERSION
+our $VERSION = '1.1'; # VERSION
 
 extends 'Log::Saftpresse::CountersOutput';
 
@@ -21,7 +21,8 @@ $Template::Stash::HASH_OPS->{ type } = sub { return 'hash'; };
 
 sub version {
 	my $version;
-        {
+  {
+    ## no critic
 		no strict 'vars'; # is only declared in build
 		$version = defined $VERSION ? $VERSION : '(git checkout)';
 	}
@@ -523,13 +524,13 @@ sub statistics_from_hashes {
 	}
 
 	foreach my $row ( @yaxis ) {
-		push(\@labeled_rows, [ $row, map { $_->{$row} } @hashes ] );
+		push(@labeled_rows, [ $row, map { $_->{$row} } @hashes ] );
 	}
 
 	foreach my $row ( @rows ) {
 		my $name = $row->[0];
 		my $values = $row->[1];
-		push(\@series, {
+		push(@series, {
 			label => $name,
 			data => [ map { [
 				$_ =~ /\d{4}-\d{2}-\d{2}/ ? 
@@ -665,7 +666,7 @@ Log::Saftpresse::CountersOutput::Html - plugin to output counters in HTML report
 
 =head1 VERSION
 
-version 1.0
+version 1.1
 
 =head1 AUTHOR
 
@@ -677,7 +678,7 @@ This software is Copyright (c) 1998 by James S. Seymour, 2015 by Markus Benning.
 
 This is free software, licensed under:
 
-  The GNU General Public License, Version 2 or later
+  The GNU General Public License, Version 2, June 1991
 
 =cut
 
